
from io import StringIO
from databind.core import datamodel
from . import from_str, from_stream, to_str, to_stream


@datamodel
class Person:
  name: str
  age: int


def test_to_str():
  assert to_str(Person('John Wick', 55)) == 'age: 55\nname: John Wick\n'
  assert to_str(Person('John Wick', 55), options=dict(sort_keys=False)) == 'name: John Wick\nage: 55\n'


def test_to_stream():
  fp = StringIO()
  to_stream(fp, Person('John Wick', 55))
  assert fp.getvalue() == 'age: 55\nname: John Wick\n'


def test_from_str():
  assert from_str(Person, 'age: 55\nname: John Wick') == Person('John Wick', 55)


def test_from_stream():
  assert from_str(Person, StringIO('age: 55\nname: John Wick')) == Person('John Wick', 55)




__author__ = 'Niklas Rosenstein <rosensteinniklas@gmail.com>'
__version__ = '0.1.0'

from typing import Any, Dict, Optional, TextIO, Type, TypeVar, Union
from databind import json as _json
from databind.core import FieldMetadata, Registry
import yaml

T = TypeVar('T')


def from_str(
  type_: Type[T],
  value: str,
  field_metadata: FieldMetadata = None,
  registry: Registry = None,
  Loader: Type[yaml.composer.Composer] = yaml.SafeLoader,
) -> T:
  return _json.from_json(type_, yaml.load(value, Loader=Loader), field_metadata, registry)


def from_stream(
  type_: Type[T],
  stream: TextIO,
  field_metadata: FieldMetadata = None,
  registry: Registry = None,
  Loader: Type[yaml.composer.Composer] = yaml.SafeLoader,
) -> T:
  return _json.from_json(type_, yaml.load(stream, Loader=Loader), field_metadata, registry)


def to_str(
  value: T,
  type_: Type[T]=None,
  field_metadata: FieldMetadata = None,
  registry: Registry=None,
  Dumper: Type[yaml.serializer.Serializer] = yaml.SafeDumper,
  options: Optional[Dict[str, Any]] = None,
) -> str:
  options = options or {}
  return yaml.dump(_json.to_json(value, type_, field_metadata, registry), Dumper=Dumper, **options)


def to_stream(
  stream: TextIO,
  value: T,
  type_: Type[T]=None,
  field_metadata: FieldMetadata = None,
  registry: Registry=None,
  Dumper: Type[yaml.serializer.Serializer] = yaml.SafeDumper,
  options: Optional[Dict[str, Any]] = None,
) -> None:
  options = options or {}
  yaml.dump(_json.to_json(value, type_, field_metadata, registry), stream, Dumper=Dumper, **options)
